Installation
============

You can install orichain with
    ``pip install orichain``

We have added Sentence Transformers and Lingua Language Detector as optional packages, so if you want to use them, please do one of the following:

For sentence-transformers:
    ``pip install "orichain[sentence-transformers]"``

For lingua-language-detector:
    ``pip install "orichain[lingua-language-detector]"``
